==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosActionsFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PodHttpChaosActionsFluent<A extends PodHttpChaosActionsFluent<A>> extends BaseFluent<A>{
  public PodHttpChaosActionsFluent() {
  }
  
  public PodHttpChaosActionsFluent(PodHttpChaosActions instance) {
    this.copyInstance(instance);
  }
  private Boolean abort;
  private String delay;
  private PodHttpChaosPatchActionsBuilder patch;
  private PodHttpChaosReplaceActionsBuilder replace;
  
  protected void copyInstance(PodHttpChaosActions instance) {
    instance = (instance != null ? instance : new PodHttpChaosActions());
    if (instance != null) {
          this.withAbort(instance.getAbort());
          this.withDelay(instance.getDelay());
          this.withPatch(instance.getPatch());
          this.withReplace(instance.getReplace());
          this.withAbort(instance.getAbort());
          this.withDelay(instance.getDelay());
          this.withPatch(instance.getPatch());
          this.withReplace(instance.getReplace());
        }
  }
  
  public Boolean getAbort() {
    return this.abort;
  }
  
  public A withAbort(Boolean abort) {
    this.abort = abort;
    return (A) this;
  }
  
  public boolean hasAbort() {
    return this.abort != null;
  }
  
  public String getDelay() {
    return this.delay;
  }
  
  public A withDelay(String delay) {
    this.delay = delay;
    return (A) this;
  }
  
  public boolean hasDelay() {
    return this.delay != null;
  }
  
  public PodHttpChaosPatchActions buildPatch() {
    return this.patch != null ? this.patch.build() : null;
  }
  
  public A withPatch(PodHttpChaosPatchActions patch) {
    this._visitables.remove(this.patch);
    if (patch != null) {
        this.patch = new PodHttpChaosPatchActionsBuilder(patch);
        this._visitables.get("patch").add(this.patch);
    } else {
        this.patch = null;
        this._visitables.get("patch").remove(this.patch);
    }
    return (A) this;
  }
  
  public boolean hasPatch() {
    return this.patch != null;
  }
  
  public PatchNested<A> withNewPatch() {
    return new PatchNested(null);
  }
  
  public PatchNested<A> withNewPatchLike(PodHttpChaosPatchActions item) {
    return new PatchNested(item);
  }
  
  public PatchNested<A> editPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(null));
  }
  
  public PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(new PodHttpChaosPatchActionsBuilder().build()));
  }
  
  public PatchNested<A> editOrNewPatchLike(PodHttpChaosPatchActions item) {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(item));
  }
  
  public PodHttpChaosReplaceActions buildReplace() {
    return this.replace != null ? this.replace.build() : null;
  }
  
  public A withReplace(PodHttpChaosReplaceActions replace) {
    this._visitables.remove(this.replace);
    if (replace != null) {
        this.replace = new PodHttpChaosReplaceActionsBuilder(replace);
        this._visitables.get("replace").add(this.replace);
    } else {
        this.replace = null;
        this._visitables.get("replace").remove(this.replace);
    }
    return (A) this;
  }
  
  public boolean hasReplace() {
    return this.replace != null;
  }
  
  public ReplaceNested<A> withNewReplace() {
    return new ReplaceNested(null);
  }
  
  public ReplaceNested<A> withNewReplaceLike(PodHttpChaosReplaceActions item) {
    return new ReplaceNested(item);
  }
  
  public ReplaceNested<A> editReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(null));
  }
  
  public ReplaceNested<A> editOrNewReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(new PodHttpChaosReplaceActionsBuilder().build()));
  }
  
  public ReplaceNested<A> editOrNewReplaceLike(PodHttpChaosReplaceActions item) {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosActionsFluent that = (PodHttpChaosActionsFluent) o;
    if (!java.util.Objects.equals(abort, that.abort)) return false;
    if (!java.util.Objects.equals(delay, that.delay)) return false;
    if (!java.util.Objects.equals(patch, that.patch)) return false;
    if (!java.util.Objects.equals(replace, that.replace)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(abort,  delay,  patch,  replace,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (replace != null) { sb.append("replace:"); sb.append(replace); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withAbort() {
    return withAbort(true);
  }
  public class PatchNested<N> extends PodHttpChaosPatchActionsFluent<PatchNested<N>> implements Nested<N>{
    PatchNested(PodHttpChaosPatchActions item) {
      this.builder = new PodHttpChaosPatchActionsBuilder(this, item);
    }
    PodHttpChaosPatchActionsBuilder builder;
    
    public N and() {
      return (N) PodHttpChaosActionsFluent.this.withPatch(builder.build());
    }
    
    public N endPatch() {
      return and();
    }
    
  
  }
  public class ReplaceNested<N> extends PodHttpChaosReplaceActionsFluent<ReplaceNested<N>> implements Nested<N>{
    ReplaceNested(PodHttpChaosReplaceActions item) {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this, item);
    }
    PodHttpChaosReplaceActionsBuilder builder;
    
    public N and() {
      return (N) PodHttpChaosActionsFluent.this.withReplace(builder.build());
    }
    
    public N endReplace() {
      return and();
    }
    
  
  }

}

==> chaosmesh-model-7.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosActionsFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PodHttpChaosActionsFluent<A extends PodHttpChaosActionsFluent<A>> extends BaseFluent<A>{
  public PodHttpChaosActionsFluent() {
  }
  
  public PodHttpChaosActionsFluent(PodHttpChaosActions instance) {
    this.copyInstance(instance);
  }
  private Boolean abort;
  private String delay;
  private PodHttpChaosPatchActionsBuilder patch;
  private PodHttpChaosReplaceActionsBuilder replace;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PodHttpChaosActions instance) {
    instance = (instance != null ? instance : new PodHttpChaosActions());
    if (instance != null) {
          this.withAbort(instance.getAbort());
          this.withDelay(instance.getDelay());
          this.withPatch(instance.getPatch());
          this.withReplace(instance.getReplace());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getAbort() {
    return this.abort;
  }
  
  public A withAbort(Boolean abort) {
    this.abort = abort;
    return (A) this;
  }
  
  public boolean hasAbort() {
    return this.abort != null;
  }
  
  public String getDelay() {
    return this.delay;
  }
  
  public A withDelay(String delay) {
    this.delay = delay;
    return (A) this;
  }
  
  public boolean hasDelay() {
    return this.delay != null;
  }
  
  public PodHttpChaosPatchActions buildPatch() {
    return this.patch != null ? this.patch.build() : null;
  }
  
  public A withPatch(PodHttpChaosPatchActions patch) {
    this._visitables.remove("patch");
    if (patch != null) {
        this.patch = new PodHttpChaosPatchActionsBuilder(patch);
        this._visitables.get("patch").add(this.patch);
    } else {
        this.patch = null;
        this._visitables.get("patch").remove(this.patch);
    }
    return (A) this;
  }
  
  public boolean hasPatch() {
    return this.patch != null;
  }
  
  public PatchNested<A> withNewPatch() {
    return new PatchNested(null);
  }
  
  public PatchNested<A> withNewPatchLike(PodHttpChaosPatchActions item) {
    return new PatchNested(item);
  }
  
  public PatchNested<A> editPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(null));
  }
  
  public PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(new PodHttpChaosPatchActionsBuilder().build()));
  }
  
  public PatchNested<A> editOrNewPatchLike(PodHttpChaosPatchActions item) {
    return withNewPatchLike(java.util.Optional.ofNullable(buildPatch()).orElse(item));
  }
  
  public PodHttpChaosReplaceActions buildReplace() {
    return this.replace != null ? this.replace.build() : null;
  }
  
  public A withReplace(PodHttpChaosReplaceActions replace) {
    this._visitables.remove("replace");
    if (replace != null) {
        this.replace = new PodHttpChaosReplaceActionsBuilder(replace);
        this._visitables.get("replace").add(this.replace);
    } else {
        this.replace = null;
        this._visitables.get("replace").remove(this.replace);
    }
    return (A) this;
  }
  
  public boolean hasReplace() {
    return this.replace != null;
  }
  
  public ReplaceNested<A> withNewReplace() {
    return new ReplaceNested(null);
  }
  
  public ReplaceNested<A> withNewReplaceLike(PodHttpChaosReplaceActions item) {
    return new ReplaceNested(item);
  }
  
  public ReplaceNested<A> editReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(null));
  }
  
  public ReplaceNested<A> editOrNewReplace() {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(new PodHttpChaosReplaceActionsBuilder().build()));
  }
  
  public ReplaceNested<A> editOrNewReplaceLike(PodHttpChaosReplaceActions item) {
    return withNewReplaceLike(java.util.Optional.ofNullable(buildReplace()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosActionsFluent that = (PodHttpChaosActionsFluent) o;
    if (!java.util.Objects.equals(abort, that.abort)) return false;
    if (!java.util.Objects.equals(delay, that.delay)) return false;
    if (!java.util.Objects.equals(patch, that.patch)) return false;
    if (!java.util.Objects.equals(replace, that.replace)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(abort,  delay,  patch,  replace,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (replace != null) { sb.append("replace:"); sb.append(replace + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withAbort() {
    return withAbort(true);
  }
  public class PatchNested<N> extends PodHttpChaosPatchActionsFluent<PatchNested<N>> implements Nested<N>{
    PatchNested(PodHttpChaosPatchActions item) {
      this.builder = new PodHttpChaosPatchActionsBuilder(this, item);
    }
    PodHttpChaosPatchActionsBuilder builder;
    
    public N and() {
      return (N) PodHttpChaosActionsFluent.this.withPatch(builder.build());
    }
    
    public N endPatch() {
      return and();
    }
    
  
  }
  public class ReplaceNested<N> extends PodHttpChaosReplaceActionsFluent<ReplaceNested<N>> implements Nested<N>{
    ReplaceNested(PodHttpChaosReplaceActions item) {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this, item);
    }
    PodHttpChaosReplaceActionsBuilder builder;
    
    public N and() {
      return (N) PodHttpChaosActionsFluent.this.withReplace(builder.build());
    }
    
    public N endReplace() {
      return and();
    }
    
  
  }

}
